netapp_ontap.models.policies_and_rules_to_be_applied_to_be_applied API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.policies_and_rules_to_be_applied_to_be_applied`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class PoliciesAndRulesToBeAppliedToBeAppliedSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the PoliciesAndRulesToBeAppliedToBeApplied object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `access_policies: List[GroupPolicyObjectCentralAccessPolicy] GET`

    The access_policies field of the policies_and_rules_to_be_applied_to_be_applied.

  `access_rules: List[GroupPolicyObjectCentralAccessRule] GET`

    The access_rules field of the policies_and_rules_to_be_applied_to_be_applied.

  `objects: List[GroupPolicyObject] GET`

    The objects field of the policies_and_rules_to_be_applied_to_be_applied.

  `restricted_groups: List[GroupPolicyObjectRestrictedGroup] GET`

    The restricted_groups field of the policies_and_rules_to_be_applied_to_be_applied.